@@ -1,5 +1,5 @@
 package Net::Stomp::Producer::Exceptions;
-$Net::Stomp::Producer::Exceptions::VERSION = '2.002';
+$Net::Stomp::Producer::Exceptions::VERSION = '2.003';
 {
   $Net::Stomp::Producer::Exceptions::DIST = 'Net-Stomp-Producer';
 }
@@ -10,7 +10,7 @@ use Net::Stomp::MooseHelpers::Exceptions;
 
 {
 package Net::Stomp::Producer::Exceptions::StackTrace;
-$Net::Stomp::Producer::Exceptions::StackTrace::VERSION = '2.002';
+$Net::Stomp::Producer::Exceptions::StackTrace::VERSION = '2.003';
 {
   $Net::Stomp::Producer::Exceptions::StackTrace::DIST = 'Net-Stomp-Producer';
 }
@@ -35,7 +35,7 @@ around _build_stack_trace_args => sub {
 
 {
 package Net::Stomp::Producer::Exceptions::BadMessage;
-$Net::Stomp::Producer::Exceptions::BadMessage::VERSION = '2.002';
+$Net::Stomp::Producer::Exceptions::BadMessage::VERSION = '2.003';
 {
   $Net::Stomp::Producer::Exceptions::BadMessage::DIST = 'Net-Stomp-Producer';
 }
@@ -61,7 +61,7 @@ __PACKAGE__->meta->make_immutable(inline_constructor=>0);
 
 {
 package Net::Stomp::Producer::Exceptions::CantSerialize;
-$Net::Stomp::Producer::Exceptions::CantSerialize::VERSION = '2.002';
+$Net::Stomp::Producer::Exceptions::CantSerialize::VERSION = '2.003';
 {
   $Net::Stomp::Producer::Exceptions::CantSerialize::DIST = 'Net-Stomp-Producer';
 }
@@ -72,7 +72,7 @@ __PACKAGE__->meta->make_immutable(inline_constructor=>0);
 
 {
 package Net::Stomp::Producer::Exceptions::BadTransformer;
-$Net::Stomp::Producer::Exceptions::BadTransformer::VERSION = '2.002';
+$Net::Stomp::Producer::Exceptions::BadTransformer::VERSION = '2.003';
 {
   $Net::Stomp::Producer::Exceptions::BadTransformer::DIST = 'Net-Stomp-Producer';
 }
@@ -90,9 +90,31 @@ sub as_string {
 __PACKAGE__->meta->make_immutable(inline_constructor=>0);
 }
 
+{
+package Net::Stomp::Producer::Exceptions::BadMethod;
+$Net::Stomp::Producer::Exceptions::BadMethod::VERSION = '2.003';
+{
+  $Net::Stomp::Producer::Exceptions::BadMethod::DIST = 'Net-Stomp-Producer';
+}
+use Moose;with 'Throwable',
+    'Net::Stomp::MooseHelpers::Exceptions::Stringy',
+    'Net::Stomp::Producer::Exceptions::StackTrace';
+use namespace::autoclean;
+has sending_method_value => ( is => 'ro', required => 1 );
+has method_to_call => ( is => 'ro', required => 1 );
+
+sub as_string {
+    my ($self) = @_;
+    sprintf qq{%s is not a valid sending method, the connection object does not have a %s method\n%s},
+        $self->sending_method_value,$self->method_to_call,
+        $self->stack_trace->as_string;
+}
+__PACKAGE__->meta->make_immutable(inline_constructor=>0);
+}
+
 {
 package Net::Stomp::Producer::Exceptions::Invalid;
-$Net::Stomp::Producer::Exceptions::Invalid::VERSION = '2.002';
+$Net::Stomp::Producer::Exceptions::Invalid::VERSION = '2.003';
 {
   $Net::Stomp::Producer::Exceptions::Invalid::DIST = 'Net-Stomp-Producer';
 }
@@ -113,7 +135,7 @@ __PACKAGE__->meta->make_immutable(inline_constructor=>0);
 
 {
 package Net::Stomp::Producer::Exceptions::Transactional;
-$Net::Stomp::Producer::Exceptions::Transactional::VERSION = '2.002';
+$Net::Stomp::Producer::Exceptions::Transactional::VERSION = '2.003';
 {
   $Net::Stomp::Producer::Exceptions::Transactional::DIST = 'Net-Stomp-Producer';
 }
@@ -144,7 +166,7 @@ Net::Stomp::Producer::Exceptions - exception classes for Net::Stomp::Producer
 
 =head1 VERSION
 
-version 2.002
+version 2.003
 
 =head1 DESCRIPTION
 
@@ -170,6 +192,14 @@ Attributes: C<transformer>, C<stack_trace>.
 
 Thrown when the transformer does not have a C<transform> method.
 
+=item C<Net::Stomp::Producer::Exceptions::BadMethod>
+
+Attributes: C<sending_method_value>, C<method_to_call>,
+C<stack_trace>.
+
+Thrown when L<Net::Stomp::Producer/sending_method> is set to a value
+that would require us to call a non-existent method on the connection.
+
 =item C<Net::Stomp::Producer::Exceptions::Invalid>
 
 Subclass of L</Net::Stomp::Producer::Exceptions::BadMessage>;
